# runtime.edge

## Purpose
Domain runtime primitives for edge.

## Owns
- Modules under `vyro.runtime.edge`.

## Entry Points
- `vyro.runtime.edge`

## Not Here
- Public app composition (`vyro.app`).
